==> vst3sdk-docs-3.7.6_build_18-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstgui/html/page_news_and_changes.js <==
var page_news_and_changes =
[
    [ "Introduction", "page_news_and_changes.html#version4_introduction", null ],
    [ "New Stuff", "page_news_and_changes.html#new_stuff", [
      [ "Version 4.11", "page_news_and_changes.html#version4_11", null ],
      [ "Version 4.10", "page_news_and_changes.html#version4_10", null ],
      [ "Version 4.9", "page_news_and_changes.html#version4_9", null ],
      [ "Version 4.8", "page_news_and_changes.html#version4_8", null ],
      [ "Version 4.7", "page_news_and_changes.html#version4_7", null ],
      [ "Version 4.6", "page_news_and_changes.html#version4_6", null ],
      [ "Version 4.5", "page_news_and_changes.html#version4_5", null ],
      [ "Version 4.4", "page_news_and_changes.html#version4_4", null ],
      [ "Version 4.3", "page_news_and_changes.html#version4_3", null ],
      [ "Version 4.2", "page_news_and_changes.html#version4_2", null ],
      [ "Version 4.1", "page_news_and_changes.html#version4_1", null ],
      [ "Version 4.0", "page_news_and_changes.html#version4_0", null ]
    ] ],
    [ "Changes for existing VSTGUI code", "page_news_and_changes.html#code_changes", [
      [ "VSTGUI 4.10 -> VSTGUI 4.11", "page_news_and_changes.html#code_changes_4_10_to_4_11", null ],
      [ "VSTGUI 4.9 -> VSTGUI 4.10", "page_news_and_changes.html#code_changes_4_9_to_4_10", null ],
      [ "VSTGUI 4.8 -> VSTGUI 4.9", "page_news_and_changes.html#code_changes_4_8_to_4_9", null ],
      [ "VSTGUI 4.7 -> VSTGUI 4.8", "page_news_and_changes.html#code_changes_4_7_to_4_8", null ],
      [ "VSTGUI 4.6 -> VSTGUI 4.7", "page_news_and_changes.html#code_changes_4_6_to_4_7", null ],
      [ "VSTGUI 4.3 -> VSTGUI 4.5", "page_news_and_changes.html#code_changes_4_3_to_4_5", null ],
      [ "VSTGUI 4.2 -> VSTGUI 4.3", "page_news_and_changes.html#code_changes_4_2_to_4_3", null ],
      [ "VSTGUI 4.1 -> VSTGUI 4.2", "page_news_and_changes.html#code_changes_4_1_to_4_2", null ],
      [ "VSTGUI 4.0 -> VSTGUI 4.1", "page_news_and_changes.html#code_changes_4_0_to_4_1", null ],
      [ "VSTGUI 3.6 -> VSTGUI 4.0", "page_news_and_changes.html#code_changes_3_6_to_4_0", null ]
    ] ],
    [ "HiDPI notes", "page_news_and_changes.html#hidpi_support", null ],
    [ "iOS support notes", "page_news_and_changes.html#ios_support", null ],
    [ "New Stuff in VSTGUI 3.6 and earlier", "page_previous_new_stuff.html", [
      [ "New mouse methods", "page_previous_new_stuff.html#new_mouse_methods", null ],
      [ "Other new things", "page_previous_new_stuff.html#other_new_things", null ],
      [ "About deprecation in version 3.6", "page_previous_new_stuff.html#about_deprecation", null ],
      [ "Code changes for existing VSTGUI 3.5 code", "page_previous_new_stuff.html#code_changes_for_3_5", null ],
      [ "Code changes for existing VSTGUI 3.0 code", "page_previous_new_stuff.html#code_changes_for_3_0", [
        [ "CView method changes", "page_previous_new_stuff.html#cviewchanges", null ],
        [ "AEffGUIEditor method changes", "page_previous_new_stuff.html#aeffguieditorchanges", null ]
      ] ],
      [ "Code changes for existing VSTGUI 2.3 code", "page_previous_new_stuff.html#code_changes_for_2_3", null ]
    ] ]
];

==> vst3sdk-docs-3.7.8_build_34-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstgui/html/page_news_and_changes.js <==
var page_news_and_changes =
[
    [ "Introduction", "page_news_and_changes.html#version4_introduction", null ],
    [ "New Stuff", "page_news_and_changes.html#new_stuff", [
      [ "Version 4.12.2", "page_news_and_changes.html#version4_12_2", null ],
      [ "Version 4.12.1", "page_news_and_changes.html#version4_12_1", null ],
      [ "Version 4.12", "page_news_and_changes.html#version4_12", null ],
      [ "Version 4.11", "page_news_and_changes.html#version4_11", null ],
      [ "Version 4.10", "page_news_and_changes.html#version4_10", null ],
      [ "Version 4.9", "page_news_and_changes.html#version4_9", null ],
      [ "Version 4.8", "page_news_and_changes.html#version4_8", null ],
      [ "Version 4.7", "page_news_and_changes.html#version4_7", null ],
      [ "Version 4.6", "page_news_and_changes.html#version4_6", null ],
      [ "Version 4.5", "page_news_and_changes.html#version4_5", null ],
      [ "Version 4.4", "page_news_and_changes.html#version4_4", null ],
      [ "Version 4.3", "page_news_and_changes.html#version4_3", null ],
      [ "Version 4.2", "page_news_and_changes.html#version4_2", null ],
      [ "Version 4.1", "page_news_and_changes.html#version4_1", null ],
      [ "Version 4.0", "page_news_and_changes.html#version4_0", null ]
    ] ],
    [ "Changes for existing VSTGUI code", "page_news_and_changes.html#code_changes", [
      [ "VSTGUI 4.11 -> VSTGUI 4.12", "page_news_and_changes.html#code_changes_4_11_to_4_12", null ],
      [ "VSTGUI 4.10 -> VSTGUI 4.11", "page_news_and_changes.html#code_changes_4_10_to_4_11", null ],
      [ "VSTGUI 4.9 -> VSTGUI 4.10", "page_news_and_changes.html#code_changes_4_9_to_4_10", null ],
      [ "VSTGUI 4.8 -> VSTGUI 4.9", "page_news_and_changes.html#code_changes_4_8_to_4_9", null ],
      [ "VSTGUI 4.7 -> VSTGUI 4.8", "page_news_and_changes.html#code_changes_4_7_to_4_8", null ],
      [ "VSTGUI 4.6 -> VSTGUI 4.7", "page_news_and_changes.html#code_changes_4_6_to_4_7", null ],
      [ "VSTGUI 4.3 -> VSTGUI 4.5", "page_news_and_changes.html#code_changes_4_3_to_4_5", null ],
      [ "VSTGUI 4.2 -> VSTGUI 4.3", "page_news_and_changes.html#code_changes_4_2_to_4_3", null ],
      [ "VSTGUI 4.1 -> VSTGUI 4.2", "page_news_and_changes.html#code_changes_4_1_to_4_2", null ],
      [ "VSTGUI 4.0 -> VSTGUI 4.1", "page_news_and_changes.html#code_changes_4_0_to_4_1", null ],
      [ "VSTGUI 3.6 -> VSTGUI 4.0", "page_news_and_changes.html#code_changes_3_6_to_4_0", null ]
    ] ],
    [ "HiDPI notes", "page_news_and_changes.html#hidpi_support", null ],
    [ "iOS support notes", "page_news_and_changes.html#ios_support", null ],
    [ "New Stuff in VSTGUI 3.6 and earlier", "page_previous_new_stuff.html", [
      [ "New mouse methods", "page_previous_new_stuff.html#new_mouse_methods", null ],
      [ "Other new things", "page_previous_new_stuff.html#other_new_things", null ],
      [ "About deprecation in version 3.6", "page_previous_new_stuff.html#about_deprecation", null ],
      [ "Code changes for existing VSTGUI 3.5 code", "page_previous_new_stuff.html#code_changes_for_3_5", null ],
      [ "Code changes for existing VSTGUI 3.0 code", "page_previous_new_stuff.html#code_changes_for_3_0", [
        [ "CView method changes", "page_previous_new_stuff.html#cviewchanges", null ],
        [ "AEffGUIEditor method changes", "page_previous_new_stuff.html#aeffguieditorchanges", null ]
      ] ],
      [ "Code changes for existing VSTGUI 2.3 code", "page_previous_new_stuff.html#code_changes_for_2_3", null ]
    ] ]
];
